@@ -2,16 +2,14 @@ package Business::CyberSource::Request::Role::Common;
 use 5.008;
 use strict;
 use warnings;
-use Carp;
 use namespace::autoclean;
 
-our $VERSION = '0.004005'; # VERSION
+our $VERSION = '0.004006'; # VERSION
 
 use Moose::Role;
 use MooseX::Types::Moose   qw( HashRef Str );
 use MooseX::Types::URI     qw( Uri     );
 use MooseX::Types::Path::Class qw( File Dir );
-use MooseX::SetOnce 0.200001;
 
 with qw(
 	Business::CyberSource::Request::Role::Credentials
@@ -43,13 +41,13 @@ sub BUILD { ## no critic qw( Subroutines::RequireFinalReturn )
 
 	if ( $self->does('Business::CyberSource::Request::Role::PurchaseInfo' ) ) {
 		unless ( $self->has_items or $self->has_total ) {
-			croak 'you must define either items or total';
+			confess 'you must define either items or total';
 		}
 	}
 
 	if ( $self->does('Business::CyberSource::Request::Role::BillingInfo' ) ) {
 		if ( $self->country eq 'US' or $self->country eq 'CA' ) {
-			croak 'zip code is required for US or Canada'
+			confess 'zip code is required for US or Canada'
 				unless $self->has_zip;
 		}
 	}
@@ -64,13 +62,6 @@ has comments => (
 	},
 );
 
-has trace => (
-	is       => 'rw',
-	isa      => 'XML::Compile::SOAP::Trace',
-	traits   => [ 'SetOnce' ],
-	init_arg => undef,
-	writer   => '_trace',
-);
 
 has _request_data => (
 	required => 1,
@@ -94,7 +85,7 @@ Business::CyberSource::Request::Role::Common - Request Role
 
 =head1 VERSION
 
-version 0.004005
+version 0.004006
 
 =head1 METHODS
 
