@@ -1,10 +1,9 @@
 package Business::CyberSource::Request::Role::PurchaseInfo;
-use 5.008;
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.004005'; # VERSION
+our $VERSION = '0.004006'; # VERSION
 
 use Moose::Role;
 with qw(
@@ -26,14 +25,13 @@ has total => (
 		my $self = shift;
 		$self->_request_data->{purchaseTotals}{grandTotalAmount} = $self->total;
 	},
-	documentation => 'Grand total for the order. You must include '
-		. 'either this field or item_#_unitPrice in your request',
 );
 
 1;
 
 # ABSTRACT: CyberSource Purchase Information Role
 
+
 __END__
 =pod
 
@@ -43,7 +41,28 @@ Business::CyberSource::Request::Role::PurchaseInfo - CyberSource Purchase Inform
 
 =head1 VERSION
 
-version 0.004005
+version 0.004006
+
+=head1 DESCRIPTION
+
+=head2 composes
+
+=over
+
+=item L<Business::CyberSource::Role::Currency>
+
+=item L<Business::CyberSource::Role::ForeignCurrency>
+
+=item L<Business::CyberSource::Request::Role::Items>
+
+=back
+
+=head1 ATTRIBUTES
+
+=head2 total
+
+Grand total for the order. You must include either this field or item unit
+price in your request.
 
 =head1 BUGS
 
