@@ -1,10 +1,9 @@
 package Business::CyberSource::Response::Role::AVS;
-use 5.008;
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.004005'; # VERSION
+our $VERSION = '0.004006'; # VERSION
 
 use Moose::Role;
 
@@ -15,7 +14,6 @@ has avs_code => (
 	predicate => 'has_avs_code',
 	is       => 'ro',
 	isa      => AVSResult,
-	documentation => 'AVS results.',
 );
 
 has avs_code_raw => (
@@ -23,14 +21,13 @@ has avs_code_raw => (
 	predicate => 'has_avs_code_raw',
 	is        => 'ro',
 	isa       => _VarcharTen,
-	documentation => 'AVS result code sent directly from the processor. '
-		. 'Returned only if a value is returned by the processor.',
 );
 
 1;
 
 # ABSTRACT: AVS Role
 
+
 __END__
 =pod
 
@@ -40,7 +37,18 @@ Business::CyberSource::Response::Role::AVS - AVS Role
 
 =head1 VERSION
 
-version 0.004005
+version 0.004006
+
+=head1 ATTRIBUTES
+
+=head2 avs_code
+
+AVS results
+
+=head2 avs_code_raw
+
+AVS result code sent directly from the processor. Returned only if a value is
+returned by the processor.
 
 =head1 BUGS
 
